# <a name="EtsiTs103601Module"></a>ASN.1 module EtsiTs103601Module
OID: _{itu-t(0) identified-organization(4) etsi(0) itsDomain(5) wg5(5) ts(103601) p2pctlresponse(1) major-version-1(1) minor-version-1(1)}_

## Imports:
* **[Ieee1609Dot2BaseTypes](Ieee1609Dot2BaseTypes.md)** *{iso(1) identified-organization(3) ieee(111) standards-association-numbered-series-standards(2) wave-stds(1609) dot2(2) base(1) base-types(2) major-version-2(2) minor-version-4(4)} WITH SUCCESSORS*<br/>
## Data Elements:
### <a name="SegmentPDU"></a>SegmentPDU
This component is the general PDU generated by the segmentation service to transmit a segment of a large message or file.
 It shall include the following components:

* _version_ of type [**Uint8**](Ieee1609Dot2BaseTypes.md#Uint8) <br>
  contains the version number of this PDU definition. For this version of this data type it shall be equal to `1`.

* _segmentationTime_ of type [**Time32**](Ieee1609Dot2BaseTypes.md#Time32) <br>
  contains information on when the message or file was segmented into 1 or several pieces.
   So the segmentationTime of all the segments for this message or file shall be the same.

* _distributedAid_ of type [**Psid**](Ieee1609Dot2BaseTypes.md#Psid) <br>
  the ITS-AID of the file. The Psid/ Its-AID is a variable length INTEGER number.

* _fileId_ of type [**HashedId8**](Ieee1609Dot2BaseTypes.md#HashedId8) <br>
  the id of the file to be distributed. It shall be set to the output of the SHA-256 hash function calculated on the transmitted CTL or file content.

* _segmentContent_ of type [**SegmentedData**](#SegmentedData) <br>
  contains the segmented data of the message or file. 

```asn1
SegmentPDU {Psid} ::= SEQUENCE {
    version           Uint8,
    segmentationTime  Time32,
    distributedAid    Psid,
    fileId            HashedId8,
    segmentContent	  SegmentedData,
    ...
}
```

### <a name="SegmentedData"></a>SegmentedData
This component represents the payload of a segment/fragment of the file data.

* _seqChunks_ of type [**SequentialChunksSegmentedData**](#SequentialChunksSegmentedData) <br>
```asn1
SegmentedData ::= CHOICE {  
    seqChunks SequentialChunksSegmentedData,
    ...
}
```

### <a name="SequentialChunksSegmentedData"></a>SequentialChunksSegmentedData
This component represents the payload of a segment/fragment of the file data when the sequential 
 segmentation method is used.  This method is applied in case the fileDescription is set to value 'FF'.
 It is composed of the following fields:

* _messageSegmentTotalNumber_ of type **INTEGER** (1..255)<br>
  the total number of segments/fragments constituting the complete file. 

* _thisMessageSegmentNumber_ of type **INTEGER** (1..255)<br>
  the number that indicates the rank or position of this segment in the ordered sequence of segments constituting the complete CTL.

* _data_ of type **OCTET STRING**  (SIZE(1..MAX))<br>
  this field represents the file segment/fragment payload.
   MAX value is equal to the maximum size of the payload contained in the Segment PDU, i.e. the MTU-GN - control fields size. MTU value depends
   on the network access technology and on the network layer. For instance, if ITS-G5 access layer
   and GeoNetworking SHB protocol is used, MTU-GN - GN-Header - BTP-Header = 1428 bytes and MAX value is calculated as:
   1428  - control fields size. 

The fields messageSegmentTotalNumber and thisMessageSegmentNumber may be present or absent depending on the use of a network/transport
 coding technique. If network/transport coding is used, these fields are unused and shall be absent.
 Note that coding technique is not specified in the current version of the standard.


 All the segments, but the last one, of the original file (e.g. the full CTL) shall have the same size equal to MAX value .
```asn1
SequentialChunksSegmentedData ::= SEQUENCE {
    messageSegmentTotalNumber	INTEGER(1..255),
    thisMessageSegmentNumber	INTEGER(1..255),
    data                        OCTET STRING (SIZE(1..MAX))
}
```

The Segmented CTL Responsemessage (SCRM) is a specific Segment PDU: it uses the parametrized data type 
 SegmentedData where the psid parameter value is set to the ITS-AID value of the CTL service as specified in 
 ETSI TS 102 965 (i.e. value 624). For the SCRM message, the size of the control information ("header" fields) is 22 bytes.

```asn1
ctlPsid Psid ::= 624
```

### <a name="ScrmPDU"></a>ScrmPDU

Values:
* **Psid** (ctlPsid)<br>
```asn1
ScrmPDU ::= SegmentPDU {Psid (ctlPsid)}
```



